@@ -4,6 +4,7 @@ import deskbar, deskbar.Handler, deskbar.Utils, deskbar.Match
 from gettext import gettext as _
 from os.path import exists
 from deskbar.defs import VERSION
+from deskbar.Utils import is_program_in_path
 
 MAX_RESULTS = 20 # per handler
 
@@ -19,8 +20,8 @@ def _show_start_beagle_dialog (dialog):
 				gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT)
 	
 	dialog.set_default_size (350, 150)
-	dialog.add_button (_("Start Beagle Daemon"), gtk.RESPONSE_ACCEPT)
 	dialog.add_button (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT)
+	dialog.add_button (_("Start Beagle Daemon"), gtk.RESPONSE_ACCEPT)
 	label = gtk.Label (_("The Beagle daemon does not appear to be running.\n You need to start it to use the Beagle Live handler."))
 	dialog.vbox.add (label)
 	label.show()
@@ -43,8 +44,11 @@ def _check_requirements():
 		return (deskbar.Handler.HANDLER_IS_NOT_APPLICABLE, "Could not load beagle, libbeagle has been compiled without python bindings:"+str(e), None)
 
 	# Check if beagled is running		
-	if not beagle.beagle_util_daemon_is_running () :
-		return (deskbar.Handler.HANDLER_HAS_REQUIREMENTS, "Beagle daemon is not running.", _show_start_beagle_dialog)
+	if not beagle.beagle_util_daemon_is_running ():
+		if is_program_in_path("beagled"):
+			return (deskbar.Handler.HANDLER_HAS_REQUIREMENTS, "Beagle daemon is not running.", _show_start_beagle_dialog)
+		else:
+			return (deskbar.Handler.HANDLER_IS_NOT_APPLICABLE, "Beagled could not be found in your $PATH. Unable to start the beagled daemon", None)
 	else:
 		return (deskbar.Handler.HANDLER_IS_HAPPY, None, None)
 	
@@ -287,14 +291,7 @@ class BeagleLiveHandler(deskbar.Handler.SignallingHandler):
 			"uri":  hit.get_uri(),
 			"type": hit.get_type(),
 		}
-		
-		if snippet != None:
-			tmp = re.sub(r"<.*?>", "", snippet)
-			tmp = re.sub(r"</.*?>", "", tmp)
-			result["snippet"] = "\n<span foreground='grey' size='small'>%s</span>" % cgi.escape(tmp)
-		else:
-			result["snippet"] = ""
-		
+			
 		name = None
 		for prop in hit_type["name"]:
 			try:
@@ -307,7 +304,7 @@ class BeagleLiveHandler(deskbar.Handler.SignallingHandler):
 					pass
 					
 			if name != None:
-				result["name"] = cgi.escape(name)
+				result["name"] = name
 				break
 		
 		if name == None:
@@ -329,18 +326,30 @@ class BeagleLiveHandler(deskbar.Handler.SignallingHandler):
 							pass
 							
 					if val != None:
-						if prop == "uri" or prop == "identifier":
-							result[prop] = val
-							result["escaped_"+prop] = cgi.escape(val)
-						else:
-							result[prop] = cgi.escape(val)
+						result[prop] = val
 						break
 					
 				if val == None:
 					#translators: This is used for unknown values returned by beagle
 					#translators: for example unknown email sender, or unknown note title
 					result[prop] = _("?")
-					
+		
+		# Escape everything for display through pango markup, except filenames. Filenames are escaped in escaped_uri or 
+		# escaped_identifier
+		for key, val in result.items():
+			if key == "uri" or key == "identifier":
+				result["escaped_"+key] = cgi.escape(val)
+			else:
+				result[key] = cgi.escape(val)
+		
+		# Add the snippet, in escaped form if available
+		if snippet != None:
+			tmp = re.sub(r"<.*?>", "", snippet)
+			tmp = re.sub(r"</.*?>", "", tmp)
+			result["snippet"] = "\n<span foreground='grey' size='small'>%s</span>" % cgi.escape(tmp)
+		else:
+			result["snippet"] = ""
+			
 		self.counter[qstring][hit.get_type()] = self.counter[qstring][hit.get_type()] +1
 
 		match = BeagleLiveMatch(self, result)
