@@ -15,12 +15,11 @@ def on_url(about, link):
 gtk.about_dialog_set_email_hook(on_email)
 gtk.about_dialog_set_url_hook(on_url)
 
-deskbar_logo = load_icon("deskbar-applet.svg", 96, 96)
 def show_about():
 	about = gtk.AboutDialog()
 	infos = {
 		"name" : _("Deskbar"),
-		"logo" : deskbar_logo,
+		"logo-icon-name" : "deskbar-applet",
 		"version" : VERSION,
 		"comments" : _("An all-in-one action bar."),
 		"copyright" : "Copyright © 2004-2006 Nigel Tao, Raphael Slinckx, Mikkel Kamstrup Erlandsen.",
@@ -38,4 +37,5 @@ def show_about():
 	for prop, val in infos.items():
 		about.set_property(prop, val)
 	
+	about.connect("response", lambda self, *args: self.destroy())
 	about.show_all()
